# -*- coding: utf-8 -*-
# Description:
# Test-suite for the Ancor Client
#
# Authors:
# Benoît Allard <benoit.allard@greenbone.net>
#
# Copyright:
# Copyright (C) 2014 Greenbone Networks GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import unittest

import fakes
from ospd_ancor.client import AncorClient

class testClient(unittest.TestCase):

    def setUp(self):
        self.client = AncorClient('server', 'good', fakes.FakeSession())

    def test_endpoint(self):
        self.assertEquals('https://server/AncorWebService/endpoint', self.client._endpoint('endpoint'))

    def test_login(self):
        self.assertFalse(self.client._has_session())
        self.assertTrue(self.client.login()) 
        self.assertTrue(self.client._has_session())

    def test_login_fails(self):
        c = AncorClient('1.2.3.4', 'bad', fakes.FakeSession())
        self.assertFalse(c._has_session())
        self.assertFalse(c.login())
        self.assertFalse(c._has_session())
        self.assertFalse(self.client.logout())
        

    def test_logout(self):
        self.assertFalse(self.client.logout())
        self.assertFalse(self.client._has_session())
        self.assertTrue(self.client.login())
        self.assertTrue(self.client.logout())
        self.assertFalse(self.client._has_session())

    def test_constructor(self):
        client = AncorClient('server', 'a\nb\nc\nd\n', fakes.FakeSession())
        self.assertEqual(client._server, 'server')
        self.assertEqual(client._key, 'abcd')
