import unittest

from ospd_ancor.wrapper import cve_metadata_severity, process_asset, process_sysinfo

class testCVEMetadataExtract(unittest.TestCase):

    def testFullInfo(self):
        s = u'CVE-2014-1541||Desc=Use-after-free vulnerability in the RefreshDriverTimer::TickDriver function in the SMIL Animation Controller in Mozilla Firefox before 30.0, Firefox ESR 24.x before 24.6, and Thunderbird before 24.6 allows remote attackers to execute arbitrary code or cause a denial of service (heap memory corruption) via crafted web content.||Score=10.0||Exploitability_score=10.0||Impact_score=10.0||Access_vector=NETWORK||Access_complexity=LOW||Availability_impact=COMPLETE||Authentication_status=NONE||Confidentiality_impact=COMPLETE||Integrity_impact=COMPLETE||Ext_ref=SECTRACK-1030386 SECTRACK http://www.securitytracker.com/id/1030386,SECTRACK-1030388 SECTRACK http://www.securitytracker.com/id/1030388,SECUNIA-58984 SECUNIA http://secunia.com/advisories/58984,SECUNIA-59052 SECUNIA http://secunia.com/advisories/59052,SECUNIA-59149 SECUNIA http://secunia.com/advisories/59149,SECUNIA-59150 SECUNIA http://secunia.com/advisories/59150,SECUNIA-59165 SECUNIA http://secunia.com/advisories/59165,SECUNIA-59169 SECUNIA http://secunia.com/advisories/59169,SECUNIA-59170 SECUNIA http://secunia.com/advisories/59170,SECUNIA-59171 SECUNIA http://secunia.com/advisories/59171,SECUNIA-59229 SECUNIA http://secunia.com/advisories/59229,SECUNIA-59275 SECUNIA http://secunia.com/advisories/59275,BID-67979 BID http://www.securityfocus.com/bid/67979,IAVM:2014-A-0082 IAVM http://iase.disa.mil/stigs/iavm-cve.html,http://linux.oracle.com/errata/ELSA-2014-0741.html CONFIRM http://linux.oracle.com/errata/ELSA-2014-0741.html,http://linux.oracle.com/errata/ELSA-2014-0742.html CONFIRM http://linux.oracle.com/errata/ELSA-2014-0742.html,http://www.mozilla.org/security/announce/2014/mfsa2014-52.html CONFIRM http://www.mozilla.org/security/announce/2014/mfsa2014-52.html,https://bugzilla.mozilla.org/show_bug.cgi?id=1000185 CONFIRM https://bugzilla.mozilla.org/show_bug.cgi?id=1000185||Publisheddate=2014-06-11||Modifieddate=2014-06-21||Generateddate=2014-06-11||Created-Date=2014-06-16||Modified-Date=2014-07-20\n'
        self.assertEqual(cve_metadata_severity(s), '10.0')

    def testNoInfo(self):
        self.assertEqual(cve_metadata_severity('null', 'def'), 'def')

class testAssetParser(unittest.TestCase):
    def testnoConcern(self):
        a = {'concerns': {'concern': []}, 'name': 'Adobe AIR x86', 'type': 'VULNERABILITY'}
        self.assertEqual([{'name': 'Adobe AIR x86'}], list(process_asset(a)))

    def testOneConcern(self):
        a = {'concerns': {'concern': [{'-type': 'VULNERABILITY', 'cve-metadata': 'null','desc': 'Unspecified vulnerability in the Java 2D component in Oracle Java via unknown vectors', 'reference': 'CVE-2010-0850'}]},'name': 'Oracle Java JDK x86', 'platform': 'cpe:/o:microsoft:windows_8.1:-:-:x64', 'product': 'cpe:/a:oracle:jdk:::x86', 'type': 'VULNERABILITY'}
        self.assertEqual([{'name': 'Oracle Java JDK x86', 'severity': '10.0', 'value': 'Unspecified vulnerability in the Java 2D component in Oracle Java via unknown vectors'}], list(process_asset(a)))

class testSysinfoParser(unittest.TestCase):
    def testOneInterface(self):
        s = {u'os_name': u'Ubuntu 13.10', u'subs_mac_addr': u'00-0C-29-35-17-D4', u'primary_host_name': u'secpod-virtual-machine', u'interfaces': {u'interface': [{u'interface_name': u'eth0', u'ip_address': u'192.168.1.120', u'mac_address': u'00-0C-29-35-17-D4'}]}, u'os_version': u'19-Ubuntu SMP Wed Oct 9 16:12:00 UTC 2013', u'subs_id': u'423031f8-f796-4a18-ad02-45b00991cbe1', u'architecture': u'i686'}
        self.assertEqual([('cpuinfo', u'i686'), ('NIC', u'eth0'), ('MAC', u'00-0C-29-35-17-D4'), ('NIC_IPS', u'192.168.1.120')], list(process_sysinfo(s)))

    def testMultipleInterfaces(self):
        s = {u'os_name': u'Microsoft Windows 7 Professional Service Pack 1', u'subs_mac_addr': u'60-67-20-ED-45-45', u'primary_host_name': u'wol001729', u'interfaces': {u'interface': [{u'interface_name': u'VMware Virtual Ethernet Adapter for VMnet1', u'ip_address': u'192.168.220.1', u'mac_address': u'00-50-56-C0-00-01'}, {u'interface_name': u'VMware Virtual Ethernet Adapter for VMnet8', u'ip_address': u'192.168.94.1', u'mac_address': u'00-50-56-C0-00-08'}, {u'interface_name': u'VirtualBox Host-Only Ethernet Adapter', u'ip_address': u'192.168.56.1', u'mac_address': u'08-00-27-00-F0-92'}, {u'interface_name': u'Intel(R) Centrino(R) Advanced-N 6205', u'ip_address': u'192.168.43.24', u'mac_address': u'60-67-20-ED-45-44'}]}, u'os_version': u'6.1.7601', u'subs_id': u'1d0f4cce-be2c-42f1-9379-86cc4afb4a7d', u'architecture': u'AMD64'}
        self.assertEqual([('cpuinfo', u'AMD64'), ('NIC', u'VMware Virtual Ethernet Adapter for VMnet1'), ('MAC', u'00-50-56-C0-00-01'), ('NIC_IPS', u'192.168.220.1')], list(process_sysinfo(s)))


